#[non_exhaustive]pub struct GetKeyLastUsageOutputBuilder { /* private fields */ }Expand description
A builder for GetKeyLastUsageOutput.
Implementations
Sourceimpl GetKeyLastUsageOutputBuilder
impl GetKeyLastUsageOutputBuilder
Sourcepub fn key_id(self, input: impl Into<String>) -> Self
pub fn key_id(self, input: impl Into<String>) -> Self
The globally unique identifier for the KMS key.
Sourcepub fn set_key_id(self, input: Option<String>) -> Self
pub fn set_key_id(self, input: Option<String>) -> Self
The globally unique identifier for the KMS key.
Sourcepub fn get_key_id(&self) -> &Option<String>
pub fn get_key_id(&self) -> &Option<String>
The globally unique identifier for the KMS key.
Sourcepub fn key_last_usage(self, input: KeyLastUsageData) -> Self
pub fn key_last_usage(self, input: KeyLastUsageData) -> Self
Contains usage information about the last time the KMS key was used for a successful cryptographic operation. If the key has not been used since tracking began, this response element is empty.
Sourcepub fn set_key_last_usage(self, input: Option<KeyLastUsageData>) -> Self
pub fn set_key_last_usage(self, input: Option<KeyLastUsageData>) -> Self
Contains usage information about the last time the KMS key was used for a successful cryptographic operation. If the key has not been used since tracking began, this response element is empty.
Sourcepub fn get_key_last_usage(&self) -> &Option<KeyLastUsageData>
pub fn get_key_last_usage(&self) -> &Option<KeyLastUsageData>
Contains usage information about the last time the KMS key was used for a successful cryptographic operation. If the key has not been used since tracking began, this response element is empty.
Sourcepub fn tracking_start_date(self, input: DateTime) -> Self
pub fn tracking_start_date(self, input: DateTime) -> Self
The date from which KMS began recording cryptographic activity for this key, or the date the KMS key was created, whichever is later.
Sourcepub fn set_tracking_start_date(self, input: Option<DateTime>) -> Self
pub fn set_tracking_start_date(self, input: Option<DateTime>) -> Self
The date from which KMS began recording cryptographic activity for this key, or the date the KMS key was created, whichever is later.
Sourcepub fn get_tracking_start_date(&self) -> &Option<DateTime>
pub fn get_tracking_start_date(&self) -> &Option<DateTime>
The date from which KMS began recording cryptographic activity for this key, or the date the KMS key was created, whichever is later.
Sourcepub fn key_creation_date(self, input: DateTime) -> Self
pub fn key_creation_date(self, input: DateTime) -> Self
The date and time when the KMS key was created.
Sourcepub fn set_key_creation_date(self, input: Option<DateTime>) -> Self
pub fn set_key_creation_date(self, input: Option<DateTime>) -> Self
The date and time when the KMS key was created.
Sourcepub fn get_key_creation_date(&self) -> &Option<DateTime>
pub fn get_key_creation_date(&self) -> &Option<DateTime>
The date and time when the KMS key was created.
Sourcepub fn build(self) -> GetKeyLastUsageOutput
pub fn build(self) -> GetKeyLastUsageOutput
Consumes the builder and constructs a GetKeyLastUsageOutput.