#[non_exhaustive]pub struct GetKeyLastUsageOutput {
pub key_id: Option<String>,
pub key_last_usage: Option<KeyLastUsageData>,
pub tracking_start_date: Option<DateTime>,
pub key_creation_date: Option<DateTime>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key_id: Option<String>The globally unique identifier for the KMS key.
key_last_usage: Option<KeyLastUsageData>Contains usage information about the last time the KMS key was used for a successful cryptographic operation. If the key has not been used since tracking began, this response element is empty.
tracking_start_date: Option<DateTime>The date from which KMS began recording cryptographic activity for this key, or the date the KMS key was created, whichever is later.
key_creation_date: Option<DateTime>The date and time when the KMS key was created.
Implementations
Sourceimpl GetKeyLastUsageOutput
impl GetKeyLastUsageOutput
Sourcepub fn key_last_usage(&self) -> Option<&KeyLastUsageData>
pub fn key_last_usage(&self) -> Option<&KeyLastUsageData>
Contains usage information about the last time the KMS key was used for a successful cryptographic operation. If the key has not been used since tracking began, this response element is empty.
Sourcepub fn tracking_start_date(&self) -> Option<&DateTime>
pub fn tracking_start_date(&self) -> Option<&DateTime>
The date from which KMS began recording cryptographic activity for this key, or the date the KMS key was created, whichever is later.
Sourcepub fn key_creation_date(&self) -> Option<&DateTime>
pub fn key_creation_date(&self) -> Option<&DateTime>
The date and time when the KMS key was created.
Sourceimpl GetKeyLastUsageOutput
impl GetKeyLastUsageOutput
Sourcepub fn builder() -> GetKeyLastUsageOutputBuilder
pub fn builder() -> GetKeyLastUsageOutputBuilder
Creates a new builder-style object to manufacture GetKeyLastUsageOutput.