KeyLastUsageData

Struct KeyLastUsageData 

#[non_exhaustive]
pub struct KeyLastUsageData { pub operation: Option<KeyLastUsageTrackingOperation>, pub timestamp: Option<DateTime>, pub cloud_trail_event_id: Option<String>, pub kms_request_id: Option<String>, }
Contains usage information about the last time the KMS key was used for a successful cryptographic operation.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
operation: Option<KeyLastUsageTrackingOperation>

The last successful cryptographic operation the KMS key was used for. Absent if the key has not been used since KMS began tracking.

timestamp: Option<DateTime>

The date and time when the KMS key was most recently used for a successful cryptographic operation. Absent if the key has not been used since KMS began tracking.

cloud_trail_event_id: Option<String>

The CloudTrail eventId associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.

kms_request_id: Option<String>

The KMS request ID associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.

Implementations

Source

impl KeyLastUsageData

pub fn operation(&self) -> Option<&KeyLastUsageTrackingOperation>

The last successful cryptographic operation the KMS key was used for. Absent if the key has not been used since KMS began tracking.

pub fn timestamp(&self) -> Option<&DateTime>

The date and time when the KMS key was most recently used for a successful cryptographic operation. Absent if the key has not been used since KMS began tracking.

pub fn cloud_trail_event_id(&self) -> Option<&str>

The CloudTrail eventId associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.

pub fn kms_request_id(&self) -> Option<&str>

The KMS request ID associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.

Source

impl KeyLastUsageData

pub fn builder() -> KeyLastUsageDataBuilder

Creates a new builder-style object to manufacture KeyLastUsageData.