#[non_exhaustive]pub enum GetKeyLastUsageError {
DependencyTimeoutException(DependencyTimeoutException),
InvalidArnException(InvalidArnException),
KmsInternalException(KmsInternalException),
NotFoundException(NotFoundException),
Unhandled(Unhandled),
}Expand description
Error type for the GetKeyLastUsageError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
DependencyTimeoutException(DependencyTimeoutException)
The system timed out while trying to fulfill the request. You can retry the request.
InvalidArnException(InvalidArnException)
The request was rejected because a specified ARN, or an ARN in a key policy, is not valid.
KmsInternalException(KmsInternalException)
The request was rejected because an internal exception occurred. The request can be retried.
NotFoundException(NotFoundException)
The request was rejected because the specified entity or resource could not be found.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl GetKeyLastUsageError
impl GetKeyLastUsageError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the GetKeyLastUsageError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the GetKeyLastUsageError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_dependency_timeout_exception(&self) -> bool
pub fn is_dependency_timeout_exception(&self) -> bool
Returns true if the error kind is GetKeyLastUsageError::DependencyTimeoutException.
Sourcepub fn is_invalid_arn_exception(&self) -> bool
pub fn is_invalid_arn_exception(&self) -> bool
Returns true if the error kind is GetKeyLastUsageError::InvalidArnException.
Sourcepub fn is_kms_internal_exception(&self) -> bool
pub fn is_kms_internal_exception(&self) -> bool
Returns true if the error kind is GetKeyLastUsageError::KmsInternalException.
Sourcepub fn is_not_found_exception(&self) -> bool
pub fn is_not_found_exception(&self) -> bool
Returns true if the error kind is GetKeyLastUsageError::NotFoundException.