#[non_exhaustive]pub struct KeyLastUsageDataBuilder { /* private fields */ }Expand description
A builder for KeyLastUsageData.
Implementations
Sourceimpl KeyLastUsageDataBuilder
impl KeyLastUsageDataBuilder
Sourcepub fn operation(self, input: KeyLastUsageTrackingOperation) -> Self
pub fn operation(self, input: KeyLastUsageTrackingOperation) -> Self
The last successful cryptographic operation the KMS key was used for. Absent if the key has not been used since KMS began tracking.
Sourcepub fn set_operation(self, input: Option<KeyLastUsageTrackingOperation>) -> Self
pub fn set_operation(self, input: Option<KeyLastUsageTrackingOperation>) -> Self
The last successful cryptographic operation the KMS key was used for. Absent if the key has not been used since KMS began tracking.
Sourcepub fn get_operation(&self) -> &Option<KeyLastUsageTrackingOperation>
pub fn get_operation(&self) -> &Option<KeyLastUsageTrackingOperation>
The last successful cryptographic operation the KMS key was used for. Absent if the key has not been used since KMS began tracking.
Sourcepub fn timestamp(self, input: DateTime) -> Self
pub fn timestamp(self, input: DateTime) -> Self
The date and time when the KMS key was most recently used for a successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourcepub fn set_timestamp(self, input: Option<DateTime>) -> Self
pub fn set_timestamp(self, input: Option<DateTime>) -> Self
The date and time when the KMS key was most recently used for a successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourcepub fn get_timestamp(&self) -> &Option<DateTime>
pub fn get_timestamp(&self) -> &Option<DateTime>
The date and time when the KMS key was most recently used for a successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourcepub fn cloud_trail_event_id(self, input: impl Into<String>) -> Self
pub fn cloud_trail_event_id(self, input: impl Into<String>) -> Self
The CloudTrail eventId associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourcepub fn set_cloud_trail_event_id(self, input: Option<String>) -> Self
pub fn set_cloud_trail_event_id(self, input: Option<String>) -> Self
The CloudTrail eventId associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourcepub fn get_cloud_trail_event_id(&self) -> &Option<String>
pub fn get_cloud_trail_event_id(&self) -> &Option<String>
The CloudTrail eventId associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourcepub fn kms_request_id(self, input: impl Into<String>) -> Self
pub fn kms_request_id(self, input: impl Into<String>) -> Self
The KMS request ID associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourcepub fn set_kms_request_id(self, input: Option<String>) -> Self
pub fn set_kms_request_id(self, input: Option<String>) -> Self
The KMS request ID associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourcepub fn get_kms_request_id(&self) -> &Option<String>
pub fn get_kms_request_id(&self) -> &Option<String>
The KMS request ID associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourcepub fn build(self) -> KeyLastUsageData
pub fn build(self) -> KeyLastUsageData
Consumes the builder and constructs a KeyLastUsageData.