#[non_exhaustive]pub struct KeyLastUsageData {
pub operation: Option<KeyLastUsageTrackingOperation>,
pub timestamp: Option<DateTime>,
pub cloud_trail_event_id: Option<String>,
pub kms_request_id: Option<String>,
}Expand description
Contains usage information about the last time the KMS key was used for a successful cryptographic operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.operation: Option<KeyLastUsageTrackingOperation>The last successful cryptographic operation the KMS key was used for. Absent if the key has not been used since KMS began tracking.
timestamp: Option<DateTime>The date and time when the KMS key was most recently used for a successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
cloud_trail_event_id: Option<String>The CloudTrail eventId associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
kms_request_id: Option<String>The KMS request ID associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Implementations
Sourceimpl KeyLastUsageData
impl KeyLastUsageData
Sourcepub fn operation(&self) -> Option<&KeyLastUsageTrackingOperation>
pub fn operation(&self) -> Option<&KeyLastUsageTrackingOperation>
The last successful cryptographic operation the KMS key was used for. Absent if the key has not been used since KMS began tracking.
Sourcepub fn timestamp(&self) -> Option<&DateTime>
pub fn timestamp(&self) -> Option<&DateTime>
The date and time when the KMS key was most recently used for a successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourcepub fn cloud_trail_event_id(&self) -> Option<&str>
pub fn cloud_trail_event_id(&self) -> Option<&str>
The CloudTrail eventId associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourcepub fn kms_request_id(&self) -> Option<&str>
pub fn kms_request_id(&self) -> Option<&str>
The KMS request ID associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
Sourceimpl KeyLastUsageData
impl KeyLastUsageData
Sourcepub fn builder() -> KeyLastUsageDataBuilder
pub fn builder() -> KeyLastUsageDataBuilder
Creates a new builder-style object to manufacture KeyLastUsageData.